@@ -22,6 +22,11 @@ namespace nl = nlohmann;
 
 using namespace pybind11::literals;
 
+inline py::module create_module(const std::string& module_name)
+{
+    return py::module_::create_extension_module(module_name.c_str(), nullptr, new py::module_::module_def);
+}
+
 TEST(nljson_serializers_tojson, none)
 {
     py::scoped_interpreter guard;
@@ -80,6 +85,7 @@ TEST(nljson_serializers_tojson, integer)
 
 TEST(nljson_serializers_tojson, float_)
 {
+    py::scoped_interpreter guard;
     py::float_ obj(36.37);
     nl::json j = obj;
 
@@ -309,8 +315,30 @@ TEST(nljson_serializers_fromjson, integer)
     ASSERT_EQ(obj2.cast<int>(), 36);
 }
 
+TEST(nljson_serializers_fromjson, integer_large_unsigned)
+{
+    // Note: if the asserts below error, the large number is printed as "-1" with
+    // an overflow error. This is only in the output step in pybind. Calling
+    // py::print on the objects shows the correct large unsigned integer.
+
+    py::scoped_interpreter guard;
+    uint64_t original = 13625394757606569013ull;
+    py::int_ py_orig = original;
+    nl::json j = original;
+    py::object obj = j;
+
+    ASSERT_TRUE(py::isinstance<py::int_>(obj));
+    ASSERT_EQ(obj.cast<uint64_t>(), original);
+
+    py::int_ obj2 = j;
+
+    // Use .equal to compare values not pointers
+    ASSERT_TRUE(obj2.equal(py_orig));
+}
+
 TEST(nljson_serializers_fromjson, float_)
 {
+    py::scoped_interpreter guard;
     nl::json j = "36.2"_json;
     py::object obj = j;
 
@@ -426,7 +454,7 @@ inline const nl::json& test_fromtojson(const nl::json& json)
 TEST(pybind11_caster_tojson, dict)
 {
     py::scoped_interpreter guard;
-    py::module m("test");
+    py::module m = create_module("test");
 
     m.def("to_json", &test_fromtojson);
 
@@ -442,7 +470,7 @@ TEST(pybind11_caster_tojson, dict)
 TEST(pybind11_caster_fromjson, dict)
 {
     py::scoped_interpreter guard;
-    py::module m("test");
+    py::module m = create_module("test");
 
     m.def("from_json", &test_fromtojson);
 
